@@ -1,7 +1,7 @@
 # constants
 
 __all__ = ['FIG_W', 'FIG_H', 'WL', 'FONT_SIZE', 'LEGEND_FONT',
-           'PLOT_FACE_COLOR', 'FIGURE_BG_COLOR']
+           'PLOT_FACE_COLOR', 'FIGURE_BG_COLOR', 'VALIDATION_EPS']
 
 FIG_W = 3.5
 FIG_H = 2.45
@@ -16,3 +16,5 @@ LEGEND_FONT = 'x-small'
 # see https://matplotlib.org/stable/gallery/color/named_colors.html
 PLOT_FACE_COLOR = 'lightsteelblue'
 FIGURE_BG_COLOR = 'aliceblue'
+VALIDATION_EPS = 1e-4
+
